/********************************************************************************/
/*										*/
/*		bounce_dialog.H 						*/
/*										*/
/*	Bouncing Balls Demo dialog box header file				*/
/*										*/
/********************************************************************************/


#ifndef BOUNCE_DIALOG_ALREADY_INCLUDED
#define BOUNCE_DIALOG_ALREADY_INCLUDED


#include "bounce_local.H"



/********************************************************************************/
/*										*/
/*	BounceDialogInfo -- generic dialog management				*/
/*										*/
/********************************************************************************/


class BounceDialogInfo : public CDialog {

protected:
   BounceManager the_manager;
   UINT resource_id;
   Bool created_flag;
   Bool ok_flag;
   Bool modal_flag;

public:
   BounceDialogInfo(BounceManager,UINT = 0);
   virtual ~BounceDialogInfo();

   virtual void activate();

private:
   DECLARE_MESSAGE_MAP();

   virtual void setupValues()					{ }

   virtual void handleApply()					{ }

protected:
   void onOK();
   void onCancel();
   void onApply();
};




/********************************************************************************/
/*										*/
/*	BounceNumberDialogInfo -- dialog for number of balls			*/
/*										*/
/********************************************************************************/


class BounceNumberDialogInfo : public BounceDialogInfo {

public:
   BounceNumberDialogInfo(BounceManager bm)
      : BounceDialogInfo(bm,IDD_NUMBER_DIALOG)			   { }

private:
   DECLARE_MESSAGE_MAP();

   void setupValues();

   void OnHScroll(UINT,UINT,CScrollBar *);
   void editUpdate(WPARAM,LPARAM);

   void handleApply();
};



/********************************************************************************/
/*										*/
/*	BounceVelocityDialogInfo -- dialog for ball velocity			*/
/*										*/
/********************************************************************************/


class BounceVelocityDialogInfo : public BounceDialogInfo {

private:
   enum { SCALE = 10 };

public:
   BounceVelocityDialogInfo(BounceManager bm)
      : BounceDialogInfo(bm,IDD_VELOCITY_DIALOG)		   { }

private:
   DECLARE_MESSAGE_MAP();

   void setupValues();
   void setEditValue(Coord v);

   void OnHScroll(UINT,UINT,CScrollBar *);
   void editUpdate(WPARAM,LPARAM);

   void handleApply();
};




/********************************************************************************/
/*										*/
/*	BouncePropertyDialogInfo -- dialog for ball properties			*/
/*										*/
/********************************************************************************/


class BouncePropertyDialogInfo : public BounceDialogInfo {

protected:
   BounceBall the_ball;

public:
   BouncePropertyDialogInfo(BounceManager bm);
   ~BouncePropertyDialogInfo();

private:
   DECLARE_MESSAGE_MAP();

   void setupValues();

   void OnHScroll(UINT,UINT,CScrollBar *);
   void editUpdate(WPARAM,LPARAM);

   void handleApply();
};




/********************************************************************************/
/*										*/
/*	BounceAboutDialogInfo -- dialog for about information			*/
/*										*/
/********************************************************************************/


class BounceAboutDialogInfo : public CDialog {

public:
   BounceAboutDialogInfo()
      : CDialog(IDD_ABOUT_DIALOG)				{ }

   Bool activateModal();
};




/********************************************************************************/
/*										*/
/*	BounceSaveFileDialogInfo -- dialog for save/save as file selection	*/
/*										*/
/********************************************************************************/


class BounceFileDialogInfo : public BounceDialogInfo {

private:
   BOOL is_open;

protected:
   BounceFileDialogInfo(BounceManager bm,BOOL open)
      : BounceDialogInfo(bm,0)
      { is_open = open; }

public:
   Bool activateModal();
};



class BounceSaveFileDialogInfo : public BounceFileDialogInfo {

public:
   BounceSaveFileDialogInfo(BounceManager bm)
      : BounceFileDialogInfo(bm,FALSE)					    { }
};




class BounceLoadFileDialogInfo : public BounceFileDialogInfo {

public:
   BounceLoadFileDialogInfo(BounceManager bm)
      : BounceFileDialogInfo(bm,TRUE)					   { }
};




#endif


/* end of bounce_dialog.H */


