/********************************************************************************/
/*										*/
/*		bounce_local.H							*/
/*										*/
/*	Header file definitions for bouncing balls demo program for windows	*/
/*										*/
/********************************************************************************/


#ifndef BOUNCE_LOCAL_ALREADY_INCLUDED
#define BOUNCE_LOCAL_ALREADY_INCLUDED

#include <afx.h>
#include <afxwin.h>
#include <afxext.h>
#include <afxcmn.h>
#include <afxtempl.h>

#include <stdlib.h>
#include <math.h>

#include <istream>
#include <sstream>
#include <ostream>
#include <fstream>
#include <string>
#include <vector>

#include "resource.h"

using namespace std;



/********************************************************************************/
/*										*/
/*	Parameters								*/
/*										*/
/********************************************************************************/


const	int		ANIM_TIME = 1000/10;
const	int		DEFAULT_NUM_BALLS = 10;
const	double		DEFAULT_RADIUS = 5.0;
const	double		DEFAULT_VELOCITY = 15.0;
const	double		MIN_VELOCITY = 0.5;
const	COLORREF	BACK_COLOR = 0xffffff;
const	COLORREF	LINE_COLOR = 0x000000;



/********************************************************************************/
/*										*/
/*	Local Types								*/
/*										*/
/********************************************************************************/


typedef int			Integer;
typedef double			Coord;
typedef const char *		ConstText;
typedef std::string		StdString;
typedef char			Character;
typedef bool			Bool;



/********************************************************************************/
/*										*/
/*	Forward type definitions						*/
/*										*/
/********************************************************************************/


typedef class BounceAppInfo *		BounceApp;
typedef class BounceWindowInfo *	BounceWindow;
typedef class BounceViewInfo *		BounceView;
typedef class BounceManagerInfo *	BounceManager;
typedef class BounceBallInfo *		BounceBall;
typedef class BounceDrawContextInfo *	BounceDrawContext;

typedef class BounceNumberDialogInfo *		BounceNumberDialog;
typedef class BounceVelocityDialogInfo *	BounceVelocityDialog;
typedef class BouncePropertyDialogInfo *	BouncePropertyDialog;
typedef class BounceAboutDialogInfo *		BounceAboutDialog;
typedef class BounceSaveFileDialogInfo *	BounceSaveFileDialog;
typedef class BounceLoadFileDialogInfo *	BounceLoadFileDialog;

typedef std::vector<BounceBall> 	BounceBallVector;



/********************************************************************************/
/*										*/
/*	Enumeration types							*/
/*										*/
/********************************************************************************/


enum BounceShape {
   BOUNCE_SHAPE_CIRCLE,
   BOUNCE_SHAPE_SQUARE,
   BOUNCE_SHAPE_DIAMOND
};



enum BounceType {
   BOUNCE_TYPE_RANDOM,
   BOUNCE_TYPE_TRUE
};



enum BounceColor {
   BOUNCE_COLOR_NONE = 0,

   BOUNCE_COLOR_BLACK = 1,
   BOUNCE_COLOR_RED = 2,
   BOUNCE_COLOR_GREEN = 4,
   BOUNCE_COLOR_YELLOW = 8,
   BOUNCE_COLOR_BLUE = 16,
   BOUNCE_COLOR_CYAN = 32,

   BOUNCE_COLOR_ALL = 63,
   BOUNCE_NUM_COLOR = 6,
   BOUNCE_MAX_COLOR = 64
};



enum BounceLine {
   BOUNCE_LINE_NONE,
   BOUNCE_LINE_SOLID,
   BOUNCE_LINE_THICK_SOLID,
   BOUNCE_LINE_DOTTED,
   BOUNCE_LINE_THICK_DOTTED,

   BOUNCE_LINE_UNDEF
};




#endif


/* end of bounce_local.H */

