/********************************************************************************/
/*										*/
/*		bouncedialog.cxx						*/
/*										*/
/*	Dialog management methods for bouncing balls demo program		*/
/*										*/
/********************************************************************************/


#include "bounce_local.H"

#include "bounce_dialog.H"
#include "bounce_manager.H"
#include "bounce_ball.H"

		

/********************************************************************************/
/*										*/
/*	Message map definitions 						*/
/*										*/
/********************************************************************************/


BEGIN_MESSAGE_MAP(BounceDialogInfo, CWnd)

   ON_COMMAND(IDOK, onOK)
   ON_COMMAND(IDCANCEL, onCancel)
   ON_COMMAND(ID_DIALOG_APPLY, onApply)

END_MESSAGE_MAP()



/********************************************************************************/
/*										*/
/*	BounceDialogInfo -- generic dialog processing				*/
/*										*/
/********************************************************************************/


BounceDialogInfo::BounceDialogInfo(BounceManager bm,UINT resid)
{
   the_manager = bm;
   ok_flag = FALSE;

   resource_id = resid;
   created_flag = FALSE;
   modal_flag = FALSE;
}



BounceDialogInfo::~BounceDialogInfo()
{
}



void
BounceDialogInfo::activate()
{
   modal_flag = FALSE;

   if (resource_id == 0) return;

   if (!created_flag) {
      Create(resource_id);
    }

   setupValues();

   ShowWindow(SW_RESTORE);
}



/********************************************************************************/
/*										*/
/*	Generic dialog callbacks						*/
/*										*/
/********************************************************************************/


void
BounceDialogInfo::onOK()
{
   handleApply();

   if (modal_flag) {
      OnOK();
    }
   else {
      DestroyWindow();
      created_flag = FALSE;
    }
}


void
BounceDialogInfo::onCancel()
{
   if (modal_flag) {
      OnCancel();
    }
   else {
      DestroyWindow();
      created_flag = FALSE;
    }
}



void
BounceDialogInfo::onApply()
{
   handleApply();
}



/********************************************************************************/
/*										*/
/*	BounceNumberDialog methods						*/
/*										*/
/********************************************************************************/



BEGIN_MESSAGE_MAP(BounceNumberDialogInfo, BounceDialogInfo)

   ON_COMMAND(IDC_NUMBER_EDIT,editUpdate)
   ON_WM_HSCROLL()

END_MESSAGE_MAP()



void
BounceNumberDialogInfo::setupValues()
{
   Integer ct = the_manager->getNumBalls();
   CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_NUMBER_SLIDER);

   sldr->SetRange(1,50,TRUE);
   sldr->SetPos(ct);

   SetDlgItemInt(IDC_NUMBER_EDIT,ct,FALSE);
}



void
BounceNumberDialogInfo::OnHScroll(UINT cd,UINT pos,CScrollBar * sc)
{
   CSliderCtrl * sldr = (CSliderCtrl *) sc;
   Integer ct = sldr->GetPos();

   if (cd != SB_ENDSCROLL) {
      SetDlgItemInt(IDC_NUMBER_EDIT,ct,FALSE);
    }
}


void
BounceNumberDialogInfo::editUpdate(WPARAM wp,LPARAM lp)
{
   BOOL fg = FALSE;
   Integer ct = GetDlgItemInt(IDC_NUMBER_EDIT,&fg);

   if (fg) {
      CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_NUMBER_SLIDER);
      sldr->SetPos(ct);
    }
}


void
BounceNumberDialogInfo::handleApply()
{
   CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_NUMBER_SLIDER);
   Integer ct = sldr->GetPos();

   the_manager->setNumBalls(ct);
   the_manager->setup();
}




/********************************************************************************/
/*										*/
/*	BounceVelocityDialog methods						*/
/*										*/
/********************************************************************************/


BEGIN_MESSAGE_MAP(BounceVelocityDialogInfo, BounceDialogInfo)

   ON_COMMAND(IDC_VELOCITY_EDIT,editUpdate)
   ON_WM_HSCROLL()

END_MESSAGE_MAP()



void
BounceVelocityDialogInfo::setupValues()
{
   Coord v = the_manager->getMaxVelocity();
   Integer ct = v*SCALE;
   CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_VELOCITY_SLIDER);

   sldr->SetRange(1*SCALE,50*SCALE,TRUE);
   sldr->SetPos(ct);

   setEditValue(v);
}



void
BounceVelocityDialogInfo::setEditValue(Coord v)
{
   ostringstream sst;

   sst << v << ends;

   SetDlgItemText(IDC_VELOCITY_EDIT,sst.str().c_str());
}



void
BounceVelocityDialogInfo::OnHScroll(UINT cd,UINT pos,CScrollBar * sc)
{
   CSliderCtrl * sldr = (CSliderCtrl *) sc;
   Coord v = sldr->GetPos();

   v /= SCALE;

   if (cd != SB_ENDSCROLL) {
      setEditValue(v);
    }
}


void
BounceVelocityDialogInfo::editUpdate(WPARAM wp,LPARAM lp)
{
   Character buf[1024];
   Integer nch = GetDlgItemText(IDC_VELOCITY_EDIT,buf,1024);
   ConstText s = buf;

   while (isspace(*s)) ++s;
   if (*s == 0) return;
   if (!isdigit(*s)) return;

   Coord v = atof(s);
   if (v < 1 || v > 50) return;
   Integer ct = v*SCALE;

   CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_VELOCITY_SLIDER);
   sldr->SetPos(ct);
}


void
BounceVelocityDialogInfo::handleApply()
{
   CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_VELOCITY_SLIDER);
   Coord v = sldr->GetPos();
   v /= SCALE;

   the_manager->setMaxVelocity(v);
   the_manager->setup();
}




/********************************************************************************/
/*										*/
/*	BouncePropertyDialog methods						*/
/*										*/
/********************************************************************************/


BEGIN_MESSAGE_MAP(BouncePropertyDialogInfo, BounceDialogInfo)

   ON_COMMAND(IDC_PROP_RADIUS_EDIT,editUpdate)
   ON_WM_HSCROLL()

END_MESSAGE_MAP()



BouncePropertyDialogInfo::BouncePropertyDialogInfo(BounceManager bm)
   : BounceDialogInfo(bm,IDD_PROPERTY_DIALOG)
{
   the_ball = bm->protoBall();
}



BouncePropertyDialogInfo::~BouncePropertyDialogInfo()
{
}




void
BouncePropertyDialogInfo::setupValues()
{
   CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_PROP_RADIUS_SLIDER);
   Coord r = the_ball->getRadius();

   sldr->SetRange(1,20,TRUE);
   sldr->SetPos(r);
   SetDlgItemInt(IDC_PROP_RADIUS_EDIT,r,FALSE);

   CComboBox * cbox = (CComboBox *) GetDlgItem(IDC_PROP_SHAPE);
   cbox->SetCurSel(the_ball->getShape());

   CListBox * lbox = (CListBox *) GetDlgItem(IDC_PROP_LINES);
   lbox->AddString("None");
   lbox->AddString("Solid");
   lbox->AddString("Thick Solid");
   lbox->AddString("Dotted");
   lbox->AddString("Thick Dotted");
   lbox->SetCurSel(the_ball->getLineStyle());

   CButton * btn;
   BOOL fg;
   BounceType bnc = the_ball->getBounce();
   BounceColor clr = the_ball->getColors();

   btn = (CButton *) GetDlgItem(IDC_PROP_RANDOM);
   fg = (bnc == BOUNCE_TYPE_RANDOM);
   btn->SetCheck(fg);

   btn = (CButton *) GetDlgItem(IDC_PROP_TRUE);
   fg = (bnc == BOUNCE_TYPE_TRUE);
   btn->SetCheck(fg);

   btn = (CButton *) GetDlgItem(IDC_PROP_BLACK);
   fg = (clr & BOUNCE_COLOR_BLACK) != 0;
   btn->SetCheck(fg);

   btn = (CButton *) GetDlgItem(IDC_PROP_RED);
   fg = (clr & BOUNCE_COLOR_RED) != 0;
   btn->SetCheck(fg);

   btn = (CButton *) GetDlgItem(IDC_PROP_GREEN);
   fg = (clr & BOUNCE_COLOR_GREEN) != 0;
   btn->SetCheck(fg);

   btn = (CButton *) GetDlgItem(IDC_PROP_YELLOW);
   fg = (clr & BOUNCE_COLOR_YELLOW) != 0;
   btn->SetCheck(fg);

   btn = (CButton *) GetDlgItem(IDC_PROP_BLUE);
   fg = (clr & BOUNCE_COLOR_BLUE) != 0;
   btn->SetCheck(fg);

   btn = (CButton *) GetDlgItem(IDC_PROP_CYAN);
   fg = (clr & BOUNCE_COLOR_CYAN) != 0;
   btn->SetCheck(fg);
}



void
BouncePropertyDialogInfo::OnHScroll(UINT cd,UINT pos,CScrollBar * sc)
{
   CSliderCtrl * sldr = (CSliderCtrl *) sc;
   Integer ct = sldr->GetPos();

   if (cd != SB_ENDSCROLL) {
      SetDlgItemInt(IDC_PROP_RADIUS_EDIT,ct,FALSE);
    }
}


void
BouncePropertyDialogInfo::editUpdate(WPARAM wp,LPARAM lp)
{
   BOOL fg = FALSE;
   Integer ct = GetDlgItemInt(IDC_PROP_RADIUS_EDIT,&fg);

   if (fg) {
      CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_PROP_RADIUS_SLIDER);
      sldr->SetPos(ct);
    }
}


void
BouncePropertyDialogInfo::handleApply()
{
   CSliderCtrl * sldr = (CSliderCtrl *) GetDlgItem(IDC_PROP_RADIUS_SLIDER);
   the_ball->setRadius(sldr->GetPos());

   CComboBox * cbox = (CComboBox *) GetDlgItem(IDC_PROP_SHAPE);
   the_ball->setShape((BounceShape) cbox->GetCurSel());

   CListBox * lbox = (CListBox *) GetDlgItem(IDC_PROP_LINES);
   the_ball->setLineStyle((BounceLine) lbox->GetCurSel());

   CButton * btn;
   BounceColor clr = BOUNCE_COLOR_NONE;

   btn = (CButton *) GetDlgItem(IDC_PROP_RANDOM);
   if (btn->GetState()) the_ball->setBounce(BOUNCE_TYPE_RANDOM);
   else the_ball->setBounce(BOUNCE_TYPE_TRUE);

   btn = (CButton *) GetDlgItem(IDC_PROP_BLACK);
   if (btn->GetState()) clr = ((BounceColor) (clr | BOUNCE_COLOR_BLACK));

   btn = (CButton *) GetDlgItem(IDC_PROP_RED);
   if (btn->GetState()) clr = ((BounceColor) (clr | BOUNCE_COLOR_RED));

   btn = (CButton *) GetDlgItem(IDC_PROP_GREEN);
   if (btn->GetState()) clr = ((BounceColor) (clr | BOUNCE_COLOR_GREEN));

   btn = (CButton *) GetDlgItem(IDC_PROP_YELLOW);
   if (btn->GetState()) clr = ((BounceColor) (clr | BOUNCE_COLOR_YELLOW));

   btn = (CButton *) GetDlgItem(IDC_PROP_BLUE);
   if (btn->GetState()) clr = ((BounceColor) (clr | BOUNCE_COLOR_BLUE));

   btn = (CButton *) GetDlgItem(IDC_PROP_CYAN);
   if (btn->GetState()) clr = ((BounceColor) (clr | BOUNCE_COLOR_CYAN));

   the_ball->setColors(clr);

   the_manager->setup();
}




/********************************************************************************/
/*										*/
/*	BounceAboutDialogInfo methods						*/
/*										*/
/********************************************************************************/


Bool
BounceAboutDialogInfo::activateModal()
{
   DoModal();

   return TRUE;
}




/********************************************************************************/
/*										*/
/*	BounceFileDialogInfo methods						*/
/*										*/
/********************************************************************************/


Bool
BounceFileDialogInfo::activateModal()
{
   CFileDialog * dlg = new CFileDialog(is_open,".bounce",the_manager->getFileName());
   int sts = dlg->DoModal();

   if (sts == IDOK) {
      the_manager->setFileName(dlg->GetPathName());
    }

   delete dlg;

   return sts == IDOK;
}



/* end of bouncedialog.cxx */






























