/********************************************************************************/
/*										*/
/*		bounceview.cxx							*/
/*										*/
/*	Viewing control methods for bouncing balls demo program 		*/
/*										*/
/********************************************************************************/


#include "bounce_local.H"

#include "bounce_view.H"
#include "bounce_manager.H"
#include "bounce_context.H"
#include "bounce_ball.H"




/********************************************************************************/
/*										*/
/*	BounceView message maps 						*/
/*										*/
/********************************************************************************/


BEGIN_MESSAGE_MAP(BounceViewInfo, CView)
   ON_WM_LBUTTONDOWN()
   ON_WM_MBUTTONDOWN()
   ON_WM_RBUTTONDOWN()
   ON_WM_KEYDOWN()
   ON_WM_SIZE()
END_MESSAGE_MAP()




/********************************************************************************/
/*										*/
/*	BounceViewInfo constructors/destructors 				*/
/*										*/
/********************************************************************************/


BounceViewInfo::BounceViewInfo()
{
   draw_context = new BounceDrawContextInfo();
   the_manager = NULL;
   x_size = -1;
   y_size = -1;
}



BounceViewInfo::~BounceViewInfo()
{ }


IMPLEMENT_DYNCREATE(BounceViewInfo,CView)



/********************************************************************************/
/*										*/
/*	BounceViewInfo drawing callback methods 				*/
/*										*/
/********************************************************************************/


void
BounceViewInfo::OnDraw(CDC* pDC)
{
   if (x_size < 0 || the_manager == NULL) {
      the_manager = (BounceManager) m_pDocument;
      draw_context->setCDC(this);
      getSize();
    }

   redraw();
}




void
BounceViewInfo::OnSize(UINT typ,int cx,int cy)
{
   getSize();
   redraw();
}




/********************************************************************************/
/*										*/
/*	BounceViewInfo event callback methods					*/
/*										*/
/********************************************************************************/


void
BounceViewInfo::OnLButtonDown(UINT fgs,CPoint)
{
   the_manager->setNumBalls(the_manager->getNumBalls()+1);
   the_manager->setup();
   nextFrame();
}



void
BounceViewInfo::OnMButtonDown(UINT,CPoint)
{
   Integer ct = the_manager->getNumBalls();

   if (ct > 1) {
      the_manager->setNumBalls(ct-1);
      the_manager->setup();
      redraw();
    }
}



void
BounceViewInfo::OnRButtonDown(UINT,CPoint)
{
   the_manager->restart();
   nextFrame();
}



void
BounceViewInfo::OnKeyDown(UINT key,UINT rpt,UINT fgs)
{
   if (key == 'R' || key == 'r') {
      the_manager->restart();
      nextFrame();
    }
   else if (key == 'N' || key == 'n') {
      nextFrame();
    }
}



/********************************************************************************/
/*										*/
/*	BounceViewInfo drawing methods						*/
/*										*/
/********************************************************************************/


void
BounceViewInfo::redraw()
{
   if (the_manager != NULL) the_manager->redraw(draw_context);
}



void
BounceViewInfo::getSize()
{
   RECT r;

   GetWindowRect(&r);
   x_size = r.right - r.left;
   y_size = r.bottom - r.top;
}



void
BounceViewInfo::nextFrame()
{
   if (the_manager != NULL) the_manager->nextFrame(draw_context,x_size,y_size);
}




/* end of bouncedraw.cxx */
