/********************************************************************************/
/*										*/
/*		bouncewindow.cxx						*/
/*										*/
/*	Top level window management methods for bouncing balls demo program	*/
/*										*/
/********************************************************************************/


#include "bounce_local.h"

#include "bounce_window.H"
#include "bounce_manager.H"
#include "bounce_view.H"
#include "bounce_dialog.H"
#include "bounce_ball.H"



/********************************************************************************/
/*										*/
/*	Message map definitions 						*/
/*										*/
/********************************************************************************/


BEGIN_MESSAGE_MAP(BounceWindowInfo, CFrameWnd)

   ON_WM_CREATE()
   ON_WM_TIMER()

   ON_COMMAND(ID_FILE_ABOUT, handleAbout)

   ON_COMMAND(ID_FILE_OPEN_FILE, handleOpen)
   ON_COMMAND(ID_FILE_SAVE_FILE, handleSave)
   ON_COMMAND(ID_FILE_SAVEAS, handleSaveAs)
   ON_COMMAND(ID_FILE_QUIT, handleQuit)

   ON_COMMAND(ID_ANIM_GO, handleGo)
   ON_COMMAND(ID_ANIM_PAUSE, handlePause)
   ON_COMMAND(ID_ANIM_RESTART, handleRestart)

   ON_COMMAND(ID_BALL_NUMBER, handleSetNumber)
   ON_COMMAND(ID_BALL_SPEED, handleSetSpeed)
   ON_COMMAND(ID_BALL_PROPS, handleSetProperties)

END_MESSAGE_MAP()




/********************************************************************************/
/*										*/
/*	BounceWindowInfo constructors/destructors				*/
/*										*/
/********************************************************************************/


BounceWindowInfo::BounceWindowInfo()
{
   anim_id = 0;

   number_dialog = NULL;
   velocity_dialog = NULL;
   property_dialog = NULL;
   about_dialog = NULL;
   save_dialog = NULL;
   load_dialog = NULL;

   the_manager = NULL;
   draw_control = NULL;
}



BounceWindowInfo::~BounceWindowInfo()
{
   delete number_dialog;
   delete velocity_dialog;
   delete property_dialog;
   delete about_dialog;
   delete save_dialog;
   delete load_dialog;
}


IMPLEMENT_DYNCREATE(BounceWindowInfo, CFrameWnd)



/********************************************************************************/
/*										*/
/*	BounceWindowInfo setup methods						*/
/*										*/
/********************************************************************************/


int
BounceWindowInfo::OnCreate(LPCREATESTRUCT lpc)
{
   if (CFrameWnd::OnCreate(lpc) == -1) return -1;

   return 0;
}


void
BounceWindowInfo::setup()
{
   if (the_manager != NULL) return;

   the_manager = (BounceManager) GetActiveDocument();

   number_dialog = new BounceNumberDialogInfo(the_manager);
   velocity_dialog = new BounceVelocityDialogInfo(the_manager);
   property_dialog = new BouncePropertyDialogInfo(the_manager);
   about_dialog = new BounceAboutDialogInfo();
   save_dialog = new BounceSaveFileDialogInfo(the_manager);
   load_dialog = new BounceLoadFileDialogInfo(the_manager);

   the_manager->setup();
}



/********************************************************************************/
/*										*/
/*	BounceWindowInfo methods to handle window buttons			*/
/*										*/
/********************************************************************************/


void
BounceWindowInfo::handleAbout() 		{ about_dialog->activateModal(); }

void
BounceWindowInfo::handleQuit()			{ exit(0); }

void
BounceWindowInfo::handleRestart()		{ the_manager->restart(); }

void
BounceWindowInfo::handleSetNumber()		{ number_dialog->activate(); }

void
BounceWindowInfo::handleSetSpeed()		{ velocity_dialog->activate(); }

void
BounceWindowInfo::handleSetProperties() 	{ property_dialog->activate(); }



/********************************************************************************/
/*										*/
/*	BounceWindowInfo animation methods					*/
/*										*/
/********************************************************************************/


void
BounceWindowInfo::handleGo()
{
   if (anim_id == NULL) {
      anim_id = SetTimer(1,ANIM_TIME,NULL);
      the_manager->setup();
    }
}



void
BounceWindowInfo::handlePause()
{
   if (anim_id != NULL) {
      KillTimer(anim_id);
      anim_id = NULL;
    }
}



void
BounceWindowInfo::OnTimer(UINT t)
{
    draw_control = (BounceView) GetActiveView();
    draw_control->nextFrame();
}




/********************************************************************************/
/*										*/
/*	BounceWindowInfo file management methods				*/
/*										*/
/********************************************************************************/


void
BounceWindowInfo::handleOpen()
{
   if (load_dialog->activateModal()) the_manager->load();
}



void
BounceWindowInfo::handleSave()
{
   ConstText fn = the_manager->getFileName();

   if (fn == NULL || *fn == 0) {
      if (!save_dialog->activateModal()) return;
    }

   the_manager->save();
}



void
BounceWindowInfo::handleSaveAs()
{
   if (save_dialog->activateModal()) the_manager->save();
}




/* end of bouncewindow.cxx */
